# Distinctiveness Centrality - Python
A Python library to calculate Distinctiveness Centrality in social networks. 

Distinctiveness Centrality is a new set of network metrics which attribute larger importance to distinctive connections. This provides an alternative view to that of some established metrics, which identify central nodes based on their brokerage power, the number and weight of their connections, and their ability to quickly reach all other nodes.

Formulas and full descriptions are provided in [this paper](https://doi.org/10.1371/journal.pone.0233276).

## Installation
```python
pip install distinctiveness
```

## Quick Start and Tutorials
- A quick-start demo is in [this notebook](DistinctivenessCentralityDemo.ipynb), while a more advanced use case is presented [here](DistinctivenessByAttribute.ipynb).
- The package documentation is documented [here](https://iandreafc.github.io/distinctiveness/).


## Please cite as
Fronzetti Colladon, A., & Naldi, M. (2020). Distinctiveness Centrality in Social Networks. *PLoS ONE*, *15*(5), e0233276. [https://doi.org/10.1371/journal.pone.0233276](https://doi.org/10.1371/journal.pone.0233276)
